@@ -10,6 +10,7 @@ pub mod alert;
 pub mod metrics;
 pub mod task;
 pub mod use_case;
+pub mod query;
 use dataset::{SiemDataset, SiemDatasetType};
 use std::collections::{BTreeMap};
 use std::sync::{Arc, Mutex};
@@ -66,5 +67,5 @@ pub trait SiemDatasetManager : Send {
     fn get_datasets(&self) -> Arc<Mutex<BTreeMap<SiemDatasetType,SiemDataset>>>;
 
     /// Sets the map of components that need dataset updates
-    fn set_dataset_channels(&mut self, channels : Arc<Mutex<BTreeMap<u64,Vec<Sender<SiemMessage>>>>>);
+    fn set_dataset_channels(&mut self, channels : Arc<Mutex<BTreeMap<SiemDatasetType,Vec<Sender<SiemMessage>>>>>);
 }
\ No newline at end of file
